#
## Copyright (C) 2001-2024 Graeme Walker <graeme_walker@users.sourceforge.net>
## 
## This program is free software: you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
# libresslbuild.mak
#

CONFIG = release
ARCH = x64
BUILD_DIR = .
SRC_DIR = ..
CFLAGS_EXTRA =

!if exist(libresslbuild.cfg)
!include libresslbuild.cfg
!endif

!if "$(CONFIG)" == "release"
SSL_FLAGS_CONFIG = $(SSL_FLAGS_RELEASE)
CRYPTO_FLAGS_CONFIG = $(CRYPTO_FLAGS_RELEASE)
!else
SSL_FLAGS_CONFIG = $(SSL_FLAGS_DEBUG)
CRYPTO_FLAGS_CONFIG = $(CRYPTO_FLAGS_DEBUG)
!endif

.PHONY: all
all: init ssl_lib crypto_lib

.PHONY: init
init:
	-mkdir $(BUILD_DIR:/=\)\library\$(CONFIG) 2>NUL:
	-mkdir $(BUILD_DIR:/=\)\ssl_obj.dir\$(CONFIG) 2>NUL:
	-mkdir $(BUILD_DIR:/=\)\crypto_obj.dir\$(CONFIG) 2>NUL:

.PHONY: ssl_lib
SSL_LIB = $(BUILD_DIR)/library/$(CONFIG)/ssl.lib
ssl_lib: $(SSL_LIB)

.PHONY: crypto_lib
CRYPTO_LIB = $(BUILD_DIR)/library/$(CONFIG)/crypto.lib
crypto_lib: $(CRYPTO_LIB)

SSL_FLAGS_DEBUG = \
    /UNDEBUG \
    /MTd \
    /Ob0 \
    /Od \
    /RTC1 \
    /Zi

SSL_FLAGS_RELEASE = \
    /DNDEBUG \
    /MT \
    /Ob2 \
    /O2

SSL_FLAGS = \
    /DCMAKE_INTDIR=\"$(CONFIG)\" \
    /DCPPFLAGS \
    /DHAVE_STRNLEN \
    /DLIBRESSL_INTERNAL \
    /DNO_CRYPT \
    /DNO_SYSLOG \
    /DOPENSSL_NO_HW_PADLOCK \
    /DWIN32 \
    /DWIN32_LEAN_AND_MEAN \
    /D_CRT_DEPRECATED_NO_WARNINGS \
    /D_CRT_SECURE_NO_WARNINGS \
    /D_GNU_SOURCE \
    /D_MBCS \
    /D_POSIX \
    /D_POSIX_SOURCE \
    /D_POSIX_THREAD_SAFE_FUNCTIONS \
    /D_REENTRANT \
    /D_WIN32_WINNT=0x0600 \
    /D_WINDOWS \
    /D__BEGIN_HIDDEN_DECLS=  \
    /D__END_HIDDEN_DECLS=  \
    /D__USE_MINGW_ANSI_STDIO \
    /Dinline=__inline \
    /I"$(SRC_DIR)/ssl/." \
    /I"$(SRC_DIR)/ssl/hidden" \
    /I"$(SRC_DIR)/ssl/../crypto/bio" \
    /I"$(SRC_DIR)/ssl/../include/compat" \
    /I"$(SRC_DIR)/ssl/../include" \
    /I"$(BUILD_DIR)/include" \
    /GS \
    /Gd \
    /Gm- \
    /MP \
    /TC \
    /W4 \
    /WX- \
    /Zc:forScope \
    /Zc:inline \
    /Zc:wchar_t \
    /fp:precise \
    /wd4018 \
    /wd4057 \
    /wd4100 \
    /wd4127 \
    /wd4146 \
    /wd4244 \
    /wd4245 \
    /wd4267 \
    /wd4389 \
    /wd4706 \
    /wd4996 \
    /Fo"$(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/" \
    /Fd"$(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_obj.pdb"

SSL_SOURCES = \
    $(SRC_DIR)/ssl/bio_ssl.c \
    $(SRC_DIR)/ssl/d1_both.c \
    $(SRC_DIR)/ssl/d1_lib.c \
    $(SRC_DIR)/ssl/d1_pkt.c \
    $(SRC_DIR)/ssl/d1_srtp.c \
    $(SRC_DIR)/ssl/pqueue.c \
    $(SRC_DIR)/ssl/s3_cbc.c \
    $(SRC_DIR)/ssl/s3_lib.c \
    $(SRC_DIR)/ssl/ssl_algs.c \
    $(SRC_DIR)/ssl/ssl_asn1.c \
    $(SRC_DIR)/ssl/ssl_both.c \
    $(SRC_DIR)/ssl/ssl_cert.c \
    $(SRC_DIR)/ssl/ssl_ciph.c \
    $(SRC_DIR)/ssl/ssl_ciphers.c \
    $(SRC_DIR)/ssl/ssl_clnt.c \
    $(SRC_DIR)/ssl/ssl_err.c \
    $(SRC_DIR)/ssl/ssl_init.c \
    $(SRC_DIR)/ssl/ssl_kex.c \
    $(SRC_DIR)/ssl/ssl_lib.c \
    $(SRC_DIR)/ssl/ssl_methods.c \
    $(SRC_DIR)/ssl/ssl_packet.c \
    $(SRC_DIR)/ssl/ssl_pkt.c \
    $(SRC_DIR)/ssl/ssl_rsa.c \
    $(SRC_DIR)/ssl/ssl_seclevel.c \
    $(SRC_DIR)/ssl/ssl_sess.c \
    $(SRC_DIR)/ssl/ssl_sigalgs.c \
    $(SRC_DIR)/ssl/ssl_srvr.c \
    $(SRC_DIR)/ssl/ssl_stat.c \
    $(SRC_DIR)/ssl/ssl_tlsext.c \
    $(SRC_DIR)/ssl/ssl_transcript.c \
    $(SRC_DIR)/ssl/ssl_txt.c \
    $(SRC_DIR)/ssl/ssl_versions.c \
    $(SRC_DIR)/ssl/t1_enc.c \
    $(SRC_DIR)/ssl/t1_lib.c \
    $(SRC_DIR)/ssl/tls_buffer.c \
    $(SRC_DIR)/ssl/tls_content.c \
    $(SRC_DIR)/ssl/tls_key_share.c \
    $(SRC_DIR)/ssl/tls_lib.c \
    $(SRC_DIR)/ssl/tls12_key_schedule.c \
    $(SRC_DIR)/ssl/tls12_lib.c \
    $(SRC_DIR)/ssl/tls12_record_layer.c \
    $(SRC_DIR)/ssl/tls13_client.c \
    $(SRC_DIR)/ssl/tls13_error.c \
    $(SRC_DIR)/ssl/tls13_handshake.c \
    $(SRC_DIR)/ssl/tls13_handshake_msg.c \
    $(SRC_DIR)/ssl/tls13_key_schedule.c \
    $(SRC_DIR)/ssl/tls13_legacy.c \
    $(SRC_DIR)/ssl/tls13_lib.c \
    $(SRC_DIR)/ssl/tls13_quic.c \
    $(SRC_DIR)/ssl/tls13_record.c \
    $(SRC_DIR)/ssl/tls13_record_layer.c \
    $(SRC_DIR)/ssl/tls13_server.c

SSL_OBJECTS = \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/bio_ssl.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/d1_both.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/d1_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/d1_pkt.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/d1_srtp.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/pqueue.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/s3_cbc.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/s3_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_algs.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_asn1.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_both.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_cert.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_ciph.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_ciphers.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_clnt.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_err.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_init.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_kex.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_methods.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_packet.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_pkt.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_rsa.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_seclevel.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_sess.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_sigalgs.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_srvr.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_stat.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_tlsext.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_transcript.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_txt.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/ssl_versions.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/t1_enc.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/t1_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls_buffer.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls_content.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls_key_share.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls12_key_schedule.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls12_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls12_record_layer.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_client.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_error.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_handshake.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_handshake_msg.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_key_schedule.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_legacy.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_lib.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_quic.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_record.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_record_layer.obj \
    $(BUILD_DIR)/ssl_obj.dir/$(CONFIG)/tls13_server.obj


CRYPTO_FLAGS_DEBUG = \
    /UNDEBUG \
    /MTd \
    /Ob0 \
    /Od \
    /RTC1 \
    /Zi

CRYPTO_FLAGS_RELEASE = \
    /DNDEBUG \
    /MT \
    /Ob2 \
    /O2

CRYPTO_FLAGS = \
    /DCMAKE_INTDIR=\"$(CONFIG)\" \
    /DCPPFLAGS \
    /DHAVE_STRNLEN \
    /DLIBRESSL_CRYPTO_INTERNAL \
    /DLIBRESSL_INTERNAL \
    /DNO_CRYPT \
    /DNO_SYSLOG \
    /DOPENSSLDIR=\"C:/Windows/libressl/ssl\" \
    /DOPENSSL_NO_ASM \
    /DOPENSSL_NO_HW_PADLOCK \
    /DWIN32 \
    /DWIN32_LEAN_AND_MEAN \
    /D_CRT_DEPRECATED_NO_WARNINGS \
    /D_CRT_SECURE_NO_WARNINGS \
    /D_GNU_SOURCE \
    /D_MBCS \
    /D_POSIX \
    /D_POSIX_SOURCE \
    /D_POSIX_THREAD_SAFE_FUNCTIONS \
    /D_REENTRANT \
    /D_WIN32_WINNT=0x0600 \
    /D_WINDOWS \
    /D__BEGIN_HIDDEN_DECLS=  \
    /D__END_HIDDEN_DECLS=  \
    /D__USE_MINGW_ANSI_STDIO \
    /Dinline=__inline \
    /I"$(SRC_DIR)/crypto/." \
    /I"$(SRC_DIR)/crypto/asn1" \
    /I"$(SRC_DIR)/crypto/bio" \
    /I"$(SRC_DIR)/crypto/bn" \
    /I"$(SRC_DIR)/crypto/bytestring" \
    /I"$(SRC_DIR)/crypto/dh" \
    /I"$(SRC_DIR)/crypto/dsa" \
    /I"$(SRC_DIR)/crypto/curve25519" \
    /I"$(SRC_DIR)/crypto/ec" \
    /I"$(SRC_DIR)/crypto/ecdh" \
    /I"$(SRC_DIR)/crypto/ecdsa" \
    /I"$(SRC_DIR)/crypto/evp" \
    /I"$(SRC_DIR)/crypto/hidden" \
    /I"$(SRC_DIR)/crypto/hmac" \
    /I"$(SRC_DIR)/crypto/modes" \
    /I"$(SRC_DIR)/crypto/ocsp" \
    /I"$(SRC_DIR)/crypto/pkcs12" \
    /I"$(SRC_DIR)/crypto/rsa" \
    /I"$(SRC_DIR)/crypto/sha" \
    /I"$(SRC_DIR)/crypto/x509" \
    /I"$(SRC_DIR)/crypto/../include/compat" \
    /I"$(SRC_DIR)/crypto/../include" \
    /I"$(BUILD_DIR)/include" \
    /I"$(SRC_DIR)/crypto/bn/arch/amd64" \
    /GS \
    /Gd \
    /Gm- \
    /MP \
    /TC \
    /W4 \
    /WX- \
    /Zc:forScope \
    /Zc:inline \
    /Zc:wchar_t \
    /fp:precise \
    /wd4018 \
    /wd4057 \
    /wd4100 \
    /wd4127 \
    /wd4146 \
    /wd4244 \
    /wd4245 \
    /wd4267 \
    /wd4389 \
    /wd4706 \
    /wd4996 \
    /Fo"$(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/" \
    /Fd"$(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/crypto_obj.pdb"

CRYPTO_SOURCES = \
    $(SRC_DIR)/crypto/aes/aes_core.c \
    $(SRC_DIR)/crypto/aes/aes_cbc.c \
    $(SRC_DIR)/crypto/camellia/camellia.c \
    $(SRC_DIR)/crypto/camellia/cmll_cbc.c \
    $(SRC_DIR)/crypto/rc4/rc4_enc.c \
    $(SRC_DIR)/crypto/rc4/rc4_skey.c \
    $(SRC_DIR)/crypto/whrlpool/wp_block.c \
    $(SRC_DIR)/crypto/cpt_err.c \
    $(SRC_DIR)/crypto/cryptlib.c \
    $(SRC_DIR)/crypto/crypto_init.c \
    $(SRC_DIR)/crypto/cversion.c \
    $(SRC_DIR)/crypto/ex_data.c \
    $(SRC_DIR)/crypto/malloc-wrapper.c \
    $(SRC_DIR)/crypto/mem_clr.c \
    $(SRC_DIR)/crypto/mem_dbg.c \
    $(SRC_DIR)/crypto/o_fips.c \
    $(SRC_DIR)/crypto/o_init.c \
    $(SRC_DIR)/crypto/o_str.c \
    $(SRC_DIR)/crypto/aes/aes_cfb.c \
    $(SRC_DIR)/crypto/aes/aes_ctr.c \
    $(SRC_DIR)/crypto/aes/aes_ecb.c \
    $(SRC_DIR)/crypto/aes/aes_ige.c \
    $(SRC_DIR)/crypto/aes/aes_ofb.c \
    $(SRC_DIR)/crypto/aes/aes_wrap.c \
    $(SRC_DIR)/crypto/asn1/a_bitstr.c \
    $(SRC_DIR)/crypto/asn1/a_enum.c \
    $(SRC_DIR)/crypto/asn1/a_int.c \
    $(SRC_DIR)/crypto/asn1/a_mbstr.c \
    $(SRC_DIR)/crypto/asn1/a_object.c \
    $(SRC_DIR)/crypto/asn1/a_octet.c \
    $(SRC_DIR)/crypto/asn1/a_pkey.c \
    $(SRC_DIR)/crypto/asn1/a_print.c \
    $(SRC_DIR)/crypto/asn1/a_pubkey.c \
    $(SRC_DIR)/crypto/asn1/a_strex.c \
    $(SRC_DIR)/crypto/asn1/a_string.c \
    $(SRC_DIR)/crypto/asn1/a_strnid.c \
    $(SRC_DIR)/crypto/asn1/a_time.c \
    $(SRC_DIR)/crypto/asn1/a_time_posix.c \
    $(SRC_DIR)/crypto/asn1/a_time_tm.c \
    $(SRC_DIR)/crypto/asn1/a_type.c \
    $(SRC_DIR)/crypto/asn1/a_utf8.c \
    $(SRC_DIR)/crypto/asn1/ameth_lib.c \
    $(SRC_DIR)/crypto/asn1/asn1_err.c \
    $(SRC_DIR)/crypto/asn1/asn1_gen.c \
    $(SRC_DIR)/crypto/asn1/asn1_item.c \
    $(SRC_DIR)/crypto/asn1/asn1_lib.c \
    $(SRC_DIR)/crypto/asn1/asn1_old.c \
    $(SRC_DIR)/crypto/asn1/asn1_old_lib.c \
    $(SRC_DIR)/crypto/asn1/asn1_par.c \
    $(SRC_DIR)/crypto/asn1/asn1_types.c \
    $(SRC_DIR)/crypto/asn1/asn_mime.c \
    $(SRC_DIR)/crypto/asn1/asn_moid.c \
    $(SRC_DIR)/crypto/asn1/bio_asn1.c \
    $(SRC_DIR)/crypto/asn1/bio_ndef.c \
    $(SRC_DIR)/crypto/asn1/p5_pbe.c \
    $(SRC_DIR)/crypto/asn1/p5_pbev2.c \
    $(SRC_DIR)/crypto/asn1/p8_pkey.c \
    $(SRC_DIR)/crypto/asn1/t_crl.c \
    $(SRC_DIR)/crypto/asn1/t_req.c \
    $(SRC_DIR)/crypto/asn1/t_spki.c \
    $(SRC_DIR)/crypto/asn1/t_x509.c \
    $(SRC_DIR)/crypto/asn1/t_x509a.c \
    $(SRC_DIR)/crypto/asn1/tasn_dec.c \
    $(SRC_DIR)/crypto/asn1/tasn_enc.c \
    $(SRC_DIR)/crypto/asn1/tasn_fre.c \
    $(SRC_DIR)/crypto/asn1/tasn_new.c \
    $(SRC_DIR)/crypto/asn1/tasn_prn.c \
    $(SRC_DIR)/crypto/asn1/tasn_typ.c \
    $(SRC_DIR)/crypto/asn1/tasn_utl.c \
    $(SRC_DIR)/crypto/asn1/x_algor.c \
    $(SRC_DIR)/crypto/asn1/x_attrib.c \
    $(SRC_DIR)/crypto/asn1/x_bignum.c \
    $(SRC_DIR)/crypto/asn1/x_crl.c \
    $(SRC_DIR)/crypto/asn1/x_exten.c \
    $(SRC_DIR)/crypto/asn1/x_info.c \
    $(SRC_DIR)/crypto/asn1/x_long.c \
    $(SRC_DIR)/crypto/asn1/x_name.c \
    $(SRC_DIR)/crypto/asn1/x_pkey.c \
    $(SRC_DIR)/crypto/asn1/x_pubkey.c \
    $(SRC_DIR)/crypto/asn1/x_req.c \
    $(SRC_DIR)/crypto/asn1/x_sig.c \
    $(SRC_DIR)/crypto/asn1/x_spki.c \
    $(SRC_DIR)/crypto/asn1/x_val.c \
    $(SRC_DIR)/crypto/asn1/x_x509.c \
    $(SRC_DIR)/crypto/asn1/x_x509a.c \
    $(SRC_DIR)/crypto/bf/bf_cfb64.c \
    $(SRC_DIR)/crypto/bf/bf_ecb.c \
    $(SRC_DIR)/crypto/bf/bf_enc.c \
    $(SRC_DIR)/crypto/bf/bf_ofb64.c \
    $(SRC_DIR)/crypto/bf/bf_skey.c \
    $(SRC_DIR)/crypto/bio/b_dump.c \
    $(SRC_DIR)/crypto/bio/b_print.c \
    $(SRC_DIR)/crypto/bio/b_sock.c \
    $(SRC_DIR)/crypto/bio/bf_buff.c \
    $(SRC_DIR)/crypto/bio/bf_nbio.c \
    $(SRC_DIR)/crypto/bio/bf_null.c \
    $(SRC_DIR)/crypto/bio/bio_cb.c \
    $(SRC_DIR)/crypto/bio/bio_err.c \
    $(SRC_DIR)/crypto/bio/bio_lib.c \
    $(SRC_DIR)/crypto/bio/bio_meth.c \
    $(SRC_DIR)/crypto/bio/bss_acpt.c \
    $(SRC_DIR)/crypto/bio/bss_bio.c \
    $(SRC_DIR)/crypto/bio/bss_conn.c \
    $(SRC_DIR)/crypto/bio/bss_dgram.c \
    $(SRC_DIR)/crypto/bio/bss_fd.c \
    $(SRC_DIR)/crypto/bio/bss_file.c \
    $(SRC_DIR)/crypto/bio/bss_mem.c \
    $(SRC_DIR)/crypto/bio/bss_null.c \
    $(SRC_DIR)/crypto/bio/bss_sock.c \
    $(SRC_DIR)/crypto/bn/bn_add.c \
    $(SRC_DIR)/crypto/bn/bn_bpsw.c \
    $(SRC_DIR)/crypto/bn/bn_const.c \
    $(SRC_DIR)/crypto/bn/bn_convert.c \
    $(SRC_DIR)/crypto/bn/bn_ctx.c \
    $(SRC_DIR)/crypto/bn/bn_div.c \
    $(SRC_DIR)/crypto/bn/bn_err.c \
    $(SRC_DIR)/crypto/bn/bn_exp.c \
    $(SRC_DIR)/crypto/bn/bn_gcd.c \
    $(SRC_DIR)/crypto/bn/bn_isqrt.c \
    $(SRC_DIR)/crypto/bn/bn_kron.c \
    $(SRC_DIR)/crypto/bn/bn_lib.c \
    $(SRC_DIR)/crypto/bn/bn_mod.c \
    $(SRC_DIR)/crypto/bn/bn_mod_sqrt.c \
    $(SRC_DIR)/crypto/bn/bn_mont.c \
    $(SRC_DIR)/crypto/bn/bn_mul.c \
    $(SRC_DIR)/crypto/bn/bn_prime.c \
    $(SRC_DIR)/crypto/bn/bn_primitives.c \
    $(SRC_DIR)/crypto/bn/bn_print.c \
    $(SRC_DIR)/crypto/bn/bn_rand.c \
    $(SRC_DIR)/crypto/bn/bn_recp.c \
    $(SRC_DIR)/crypto/bn/bn_shift.c \
    $(SRC_DIR)/crypto/bn/bn_small_primes.c \
    $(SRC_DIR)/crypto/bn/bn_sqr.c \
    $(SRC_DIR)/crypto/bn/bn_word.c \
    $(SRC_DIR)/crypto/buffer/buf_err.c \
    $(SRC_DIR)/crypto/buffer/buffer.c \
    $(SRC_DIR)/crypto/bytestring/bs_ber.c \
    $(SRC_DIR)/crypto/bytestring/bs_cbb.c \
    $(SRC_DIR)/crypto/bytestring/bs_cbs.c \
    $(SRC_DIR)/crypto/camellia/cmll_cfb.c \
    $(SRC_DIR)/crypto/camellia/cmll_ctr.c \
    $(SRC_DIR)/crypto/camellia/cmll_ecb.c \
    $(SRC_DIR)/crypto/camellia/cmll_misc.c \
    $(SRC_DIR)/crypto/camellia/cmll_ofb.c \
    $(SRC_DIR)/crypto/cast/c_cfb64.c \
    $(SRC_DIR)/crypto/cast/c_ecb.c \
    $(SRC_DIR)/crypto/cast/c_enc.c \
    $(SRC_DIR)/crypto/cast/c_ofb64.c \
    $(SRC_DIR)/crypto/cast/c_skey.c \
    $(SRC_DIR)/crypto/chacha/chacha.c \
    $(SRC_DIR)/crypto/cmac/cm_ameth.c \
    $(SRC_DIR)/crypto/cmac/cm_pmeth.c \
    $(SRC_DIR)/crypto/cmac/cmac.c \
    $(SRC_DIR)/crypto/cms/cms_asn1.c \
    $(SRC_DIR)/crypto/cms/cms_att.c \
    $(SRC_DIR)/crypto/cms/cms_dd.c \
    $(SRC_DIR)/crypto/cms/cms_enc.c \
    $(SRC_DIR)/crypto/cms/cms_env.c \
    $(SRC_DIR)/crypto/cms/cms_err.c \
    $(SRC_DIR)/crypto/cms/cms_ess.c \
    $(SRC_DIR)/crypto/cms/cms_io.c \
    $(SRC_DIR)/crypto/cms/cms_kari.c \
    $(SRC_DIR)/crypto/cms/cms_lib.c \
    $(SRC_DIR)/crypto/cms/cms_pwri.c \
    $(SRC_DIR)/crypto/cms/cms_sd.c \
    $(SRC_DIR)/crypto/cms/cms_smime.c \
    $(SRC_DIR)/crypto/conf/conf_api.c \
    $(SRC_DIR)/crypto/conf/conf_def.c \
    $(SRC_DIR)/crypto/conf/conf_err.c \
    $(SRC_DIR)/crypto/conf/conf_lib.c \
    $(SRC_DIR)/crypto/conf/conf_mall.c \
    $(SRC_DIR)/crypto/conf/conf_mod.c \
    $(SRC_DIR)/crypto/conf/conf_sap.c \
    $(SRC_DIR)/crypto/ct/ct_b64.c \
    $(SRC_DIR)/crypto/ct/ct_err.c \
    $(SRC_DIR)/crypto/ct/ct_log.c \
    $(SRC_DIR)/crypto/ct/ct_oct.c \
    $(SRC_DIR)/crypto/ct/ct_policy.c \
    $(SRC_DIR)/crypto/ct/ct_prn.c \
    $(SRC_DIR)/crypto/ct/ct_sct.c \
    $(SRC_DIR)/crypto/ct/ct_sct_ctx.c \
    $(SRC_DIR)/crypto/ct/ct_vfy.c \
    $(SRC_DIR)/crypto/ct/ct_x509v3.c \
    $(SRC_DIR)/crypto/curve25519/curve25519-generic.c \
    $(SRC_DIR)/crypto/curve25519/curve25519.c \
    $(SRC_DIR)/crypto/des/cbc_cksm.c \
    $(SRC_DIR)/crypto/des/cbc_enc.c \
    $(SRC_DIR)/crypto/des/cfb64ede.c \
    $(SRC_DIR)/crypto/des/cfb64enc.c \
    $(SRC_DIR)/crypto/des/cfb_enc.c \
    $(SRC_DIR)/crypto/des/des_enc.c \
    $(SRC_DIR)/crypto/des/ecb3_enc.c \
    $(SRC_DIR)/crypto/des/ecb_enc.c \
    $(SRC_DIR)/crypto/des/ede_cbcm_enc.c \
    $(SRC_DIR)/crypto/des/enc_read.c \
    $(SRC_DIR)/crypto/des/enc_writ.c \
    $(SRC_DIR)/crypto/des/fcrypt.c \
    $(SRC_DIR)/crypto/des/fcrypt_b.c \
    $(SRC_DIR)/crypto/des/ofb64ede.c \
    $(SRC_DIR)/crypto/des/ofb64enc.c \
    $(SRC_DIR)/crypto/des/ofb_enc.c \
    $(SRC_DIR)/crypto/des/pcbc_enc.c \
    $(SRC_DIR)/crypto/des/qud_cksm.c \
    $(SRC_DIR)/crypto/des/rand_key.c \
    $(SRC_DIR)/crypto/des/set_key.c \
    $(SRC_DIR)/crypto/des/str2key.c \
    $(SRC_DIR)/crypto/des/xcbc_enc.c \
    $(SRC_DIR)/crypto/dh/dh_ameth.c \
    $(SRC_DIR)/crypto/dh/dh_asn1.c \
    $(SRC_DIR)/crypto/dh/dh_check.c \
    $(SRC_DIR)/crypto/dh/dh_err.c \
    $(SRC_DIR)/crypto/dh/dh_gen.c \
    $(SRC_DIR)/crypto/dh/dh_key.c \
    $(SRC_DIR)/crypto/dh/dh_lib.c \
    $(SRC_DIR)/crypto/dh/dh_pmeth.c \
    $(SRC_DIR)/crypto/dsa/dsa_ameth.c \
    $(SRC_DIR)/crypto/dsa/dsa_asn1.c \
    $(SRC_DIR)/crypto/dsa/dsa_err.c \
    $(SRC_DIR)/crypto/dsa/dsa_gen.c \
    $(SRC_DIR)/crypto/dsa/dsa_key.c \
    $(SRC_DIR)/crypto/dsa/dsa_lib.c \
    $(SRC_DIR)/crypto/dsa/dsa_meth.c \
    $(SRC_DIR)/crypto/dsa/dsa_ossl.c \
    $(SRC_DIR)/crypto/dsa/dsa_pmeth.c \
    $(SRC_DIR)/crypto/dsa/dsa_prn.c \
    $(SRC_DIR)/crypto/ec/ec_ameth.c \
    $(SRC_DIR)/crypto/ec/ec_asn1.c \
    $(SRC_DIR)/crypto/ec/ec_check.c \
    $(SRC_DIR)/crypto/ec/ec_curve.c \
    $(SRC_DIR)/crypto/ec/ec_cvt.c \
    $(SRC_DIR)/crypto/ec/ec_err.c \
    $(SRC_DIR)/crypto/ec/ec_key.c \
    $(SRC_DIR)/crypto/ec/ec_kmeth.c \
    $(SRC_DIR)/crypto/ec/ec_lib.c \
    $(SRC_DIR)/crypto/ec/ec_mult.c \
    $(SRC_DIR)/crypto/ec/ec_oct.c \
    $(SRC_DIR)/crypto/ec/ec_pmeth.c \
    $(SRC_DIR)/crypto/ec/ec_print.c \
    $(SRC_DIR)/crypto/ec/eck_prn.c \
    $(SRC_DIR)/crypto/ec/ecp_mont.c \
    $(SRC_DIR)/crypto/ec/ecp_oct.c \
    $(SRC_DIR)/crypto/ec/ecp_smpl.c \
    $(SRC_DIR)/crypto/ec/ecx_methods.c \
    $(SRC_DIR)/crypto/ecdh/ecdh.c \
    $(SRC_DIR)/crypto/ecdsa/ecdsa.c \
    $(SRC_DIR)/crypto/engine/engine_stubs.c \
    $(SRC_DIR)/crypto/err/err.c \
    $(SRC_DIR)/crypto/err/err_all.c \
    $(SRC_DIR)/crypto/err/err_prn.c \
    $(SRC_DIR)/crypto/evp/bio_b64.c \
    $(SRC_DIR)/crypto/evp/bio_enc.c \
    $(SRC_DIR)/crypto/evp/bio_md.c \
    $(SRC_DIR)/crypto/evp/c_all.c \
    $(SRC_DIR)/crypto/evp/cipher_method_lib.c \
    $(SRC_DIR)/crypto/evp/digest.c \
    $(SRC_DIR)/crypto/evp/e_aes.c \
    $(SRC_DIR)/crypto/evp/e_aes_cbc_hmac_sha1.c \
    $(SRC_DIR)/crypto/evp/e_bf.c \
    $(SRC_DIR)/crypto/evp/e_camellia.c \
    $(SRC_DIR)/crypto/evp/e_cast.c \
    $(SRC_DIR)/crypto/evp/e_chacha.c \
    $(SRC_DIR)/crypto/evp/e_chacha20poly1305.c \
    $(SRC_DIR)/crypto/evp/e_des.c \
    $(SRC_DIR)/crypto/evp/e_des3.c \
    $(SRC_DIR)/crypto/evp/e_gost2814789.c \
    $(SRC_DIR)/crypto/evp/e_idea.c \
    $(SRC_DIR)/crypto/evp/e_null.c \
    $(SRC_DIR)/crypto/evp/e_rc2.c \
    $(SRC_DIR)/crypto/evp/e_rc4.c \
    $(SRC_DIR)/crypto/evp/e_rc4_hmac_md5.c \
    $(SRC_DIR)/crypto/evp/e_sm4.c \
    $(SRC_DIR)/crypto/evp/e_xcbc_d.c \
    $(SRC_DIR)/crypto/evp/encode.c \
    $(SRC_DIR)/crypto/evp/evp_aead.c \
    $(SRC_DIR)/crypto/evp/evp_enc.c \
    $(SRC_DIR)/crypto/evp/evp_err.c \
    $(SRC_DIR)/crypto/evp/evp_key.c \
    $(SRC_DIR)/crypto/evp/evp_lib.c \
    $(SRC_DIR)/crypto/evp/evp_pbe.c \
    $(SRC_DIR)/crypto/evp/evp_pkey.c \
    $(SRC_DIR)/crypto/evp/m_gost2814789.c \
    $(SRC_DIR)/crypto/evp/m_gostr341194.c \
    $(SRC_DIR)/crypto/evp/m_md4.c \
    $(SRC_DIR)/crypto/evp/m_md5.c \
    $(SRC_DIR)/crypto/evp/m_md5_sha1.c \
    $(SRC_DIR)/crypto/evp/m_null.c \
    $(SRC_DIR)/crypto/evp/m_ripemd.c \
    $(SRC_DIR)/crypto/evp/m_sha1.c \
    $(SRC_DIR)/crypto/evp/m_sha3.c \
    $(SRC_DIR)/crypto/evp/m_sigver.c \
    $(SRC_DIR)/crypto/evp/m_streebog.c \
    $(SRC_DIR)/crypto/evp/m_sm3.c \
    $(SRC_DIR)/crypto/evp/m_wp.c \
    $(SRC_DIR)/crypto/evp/names.c \
    $(SRC_DIR)/crypto/evp/p5_crpt.c \
    $(SRC_DIR)/crypto/evp/p5_crpt2.c \
    $(SRC_DIR)/crypto/evp/p_dec.c \
    $(SRC_DIR)/crypto/evp/p_enc.c \
    $(SRC_DIR)/crypto/evp/p_lib.c \
    $(SRC_DIR)/crypto/evp/p_open.c \
    $(SRC_DIR)/crypto/evp/p_seal.c \
    $(SRC_DIR)/crypto/evp/p_sign.c \
    $(SRC_DIR)/crypto/evp/p_verify.c \
    $(SRC_DIR)/crypto/evp/pmeth_fn.c \
    $(SRC_DIR)/crypto/evp/pmeth_gn.c \
    $(SRC_DIR)/crypto/evp/pmeth_lib.c \
    $(SRC_DIR)/crypto/gost/gost2814789.c \
    $(SRC_DIR)/crypto/gost/gost89_keywrap.c \
    $(SRC_DIR)/crypto/gost/gost89_params.c \
    $(SRC_DIR)/crypto/gost/gost89imit_ameth.c \
    $(SRC_DIR)/crypto/gost/gost89imit_pmeth.c \
    $(SRC_DIR)/crypto/gost/gost_asn1.c \
    $(SRC_DIR)/crypto/gost/gost_err.c \
    $(SRC_DIR)/crypto/gost/gostr341001.c \
    $(SRC_DIR)/crypto/gost/gostr341001_ameth.c \
    $(SRC_DIR)/crypto/gost/gostr341001_key.c \
    $(SRC_DIR)/crypto/gost/gostr341001_params.c \
    $(SRC_DIR)/crypto/gost/gostr341001_pmeth.c \
    $(SRC_DIR)/crypto/gost/gostr341194.c \
    $(SRC_DIR)/crypto/gost/streebog.c \
    $(SRC_DIR)/crypto/hkdf/hkdf.c \
    $(SRC_DIR)/crypto/hmac/hm_ameth.c \
    $(SRC_DIR)/crypto/hmac/hm_pmeth.c \
    $(SRC_DIR)/crypto/hmac/hmac.c \
    $(SRC_DIR)/crypto/idea/i_cbc.c \
    $(SRC_DIR)/crypto/idea/i_cfb64.c \
    $(SRC_DIR)/crypto/idea/i_ecb.c \
    $(SRC_DIR)/crypto/idea/i_ofb64.c \
    $(SRC_DIR)/crypto/idea/i_skey.c \
    $(SRC_DIR)/crypto/kdf/hkdf_evp.c \
    $(SRC_DIR)/crypto/kdf/kdf_err.c \
    $(SRC_DIR)/crypto/lhash/lh_stats.c \
    $(SRC_DIR)/crypto/lhash/lhash.c \
    $(SRC_DIR)/crypto/md4/md4.c \
    $(SRC_DIR)/crypto/md5/md5.c \
    $(SRC_DIR)/crypto/modes/cbc128.c \
    $(SRC_DIR)/crypto/modes/ccm128.c \
    $(SRC_DIR)/crypto/modes/cfb128.c \
    $(SRC_DIR)/crypto/modes/ctr128.c \
    $(SRC_DIR)/crypto/modes/gcm128.c \
    $(SRC_DIR)/crypto/modes/ofb128.c \
    $(SRC_DIR)/crypto/modes/xts128.c \
    $(SRC_DIR)/crypto/objects/o_names.c \
    $(SRC_DIR)/crypto/objects/obj_dat.c \
    $(SRC_DIR)/crypto/objects/obj_err.c \
    $(SRC_DIR)/crypto/objects/obj_lib.c \
    $(SRC_DIR)/crypto/objects/obj_xref.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_asn.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_cl.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_err.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_ext.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_ht.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_lib.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_prn.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_srv.c \
    $(SRC_DIR)/crypto/ocsp/ocsp_vfy.c \
    $(SRC_DIR)/crypto/pem/pem_all.c \
    $(SRC_DIR)/crypto/pem/pem_err.c \
    $(SRC_DIR)/crypto/pem/pem_info.c \
    $(SRC_DIR)/crypto/pem/pem_lib.c \
    $(SRC_DIR)/crypto/pem/pem_oth.c \
    $(SRC_DIR)/crypto/pem/pem_pk8.c \
    $(SRC_DIR)/crypto/pem/pem_pkey.c \
    $(SRC_DIR)/crypto/pem/pem_sign.c \
    $(SRC_DIR)/crypto/pem/pem_x509.c \
    $(SRC_DIR)/crypto/pem/pem_xaux.c \
    $(SRC_DIR)/crypto/pem/pvkfmt.c \
    $(SRC_DIR)/crypto/pkcs12/p12_add.c \
    $(SRC_DIR)/crypto/pkcs12/p12_asn.c \
    $(SRC_DIR)/crypto/pkcs12/p12_attr.c \
    $(SRC_DIR)/crypto/pkcs12/p12_crpt.c \
    $(SRC_DIR)/crypto/pkcs12/p12_crt.c \
    $(SRC_DIR)/crypto/pkcs12/p12_decr.c \
    $(SRC_DIR)/crypto/pkcs12/p12_init.c \
    $(SRC_DIR)/crypto/pkcs12/p12_key.c \
    $(SRC_DIR)/crypto/pkcs12/p12_kiss.c \
    $(SRC_DIR)/crypto/pkcs12/p12_mutl.c \
    $(SRC_DIR)/crypto/pkcs12/p12_npas.c \
    $(SRC_DIR)/crypto/pkcs12/p12_p8d.c \
    $(SRC_DIR)/crypto/pkcs12/p12_p8e.c \
    $(SRC_DIR)/crypto/pkcs12/p12_sbag.c \
    $(SRC_DIR)/crypto/pkcs12/p12_utl.c \
    $(SRC_DIR)/crypto/pkcs12/pk12err.c \
    $(SRC_DIR)/crypto/pkcs7/pk7_asn1.c \
    $(SRC_DIR)/crypto/pkcs7/pk7_attr.c \
    $(SRC_DIR)/crypto/pkcs7/pk7_doit.c \
    $(SRC_DIR)/crypto/pkcs7/pk7_lib.c \
    $(SRC_DIR)/crypto/pkcs7/pk7_mime.c \
    $(SRC_DIR)/crypto/pkcs7/pk7_smime.c \
    $(SRC_DIR)/crypto/pkcs7/pkcs7err.c \
    $(SRC_DIR)/crypto/poly1305/poly1305.c \
    $(SRC_DIR)/crypto/rand/rand_err.c \
    $(SRC_DIR)/crypto/rand/rand_lib.c \
    $(SRC_DIR)/crypto/rand/randfile.c \
    $(SRC_DIR)/crypto/rc2/rc2_cbc.c \
    $(SRC_DIR)/crypto/rc2/rc2_ecb.c \
    $(SRC_DIR)/crypto/rc2/rc2_skey.c \
    $(SRC_DIR)/crypto/rc2/rc2cfb64.c \
    $(SRC_DIR)/crypto/rc2/rc2ofb64.c \
    $(SRC_DIR)/crypto/ripemd/ripemd.c \
    $(SRC_DIR)/crypto/rsa/rsa_ameth.c \
    $(SRC_DIR)/crypto/rsa/rsa_asn1.c \
    $(SRC_DIR)/crypto/rsa/rsa_blinding.c \
    $(SRC_DIR)/crypto/rsa/rsa_chk.c \
    $(SRC_DIR)/crypto/rsa/rsa_eay.c \
    $(SRC_DIR)/crypto/rsa/rsa_err.c \
    $(SRC_DIR)/crypto/rsa/rsa_gen.c \
    $(SRC_DIR)/crypto/rsa/rsa_lib.c \
    $(SRC_DIR)/crypto/rsa/rsa_meth.c \
    $(SRC_DIR)/crypto/rsa/rsa_none.c \
    $(SRC_DIR)/crypto/rsa/rsa_oaep.c \
    $(SRC_DIR)/crypto/rsa/rsa_pk1.c \
    $(SRC_DIR)/crypto/rsa/rsa_pmeth.c \
    $(SRC_DIR)/crypto/rsa/rsa_prn.c \
    $(SRC_DIR)/crypto/rsa/rsa_pss.c \
    $(SRC_DIR)/crypto/rsa/rsa_saos.c \
    $(SRC_DIR)/crypto/rsa/rsa_sign.c \
    $(SRC_DIR)/crypto/rsa/rsa_x931.c \
    $(SRC_DIR)/crypto/sha/sha1.c \
    $(SRC_DIR)/crypto/sha/sha256.c \
    $(SRC_DIR)/crypto/sha/sha3.c \
    $(SRC_DIR)/crypto/sha/sha512.c \
    $(SRC_DIR)/crypto/sm3/sm3.c \
    $(SRC_DIR)/crypto/sm4/sm4.c \
    $(SRC_DIR)/crypto/stack/stack.c \
    $(SRC_DIR)/crypto/ts/ts_asn1.c \
    $(SRC_DIR)/crypto/ts/ts_conf.c \
    $(SRC_DIR)/crypto/ts/ts_err.c \
    $(SRC_DIR)/crypto/ts/ts_lib.c \
    $(SRC_DIR)/crypto/ts/ts_req_print.c \
    $(SRC_DIR)/crypto/ts/ts_req_utils.c \
    $(SRC_DIR)/crypto/ts/ts_rsp_print.c \
    $(SRC_DIR)/crypto/ts/ts_rsp_sign.c \
    $(SRC_DIR)/crypto/ts/ts_rsp_utils.c \
    $(SRC_DIR)/crypto/ts/ts_rsp_verify.c \
    $(SRC_DIR)/crypto/ts/ts_verify_ctx.c \
    $(SRC_DIR)/crypto/txt_db/txt_db.c \
    $(SRC_DIR)/crypto/ui/ui_err.c \
    $(SRC_DIR)/crypto/ui/ui_lib.c \
    $(SRC_DIR)/crypto/ui/ui_null.c \
    $(SRC_DIR)/crypto/ui/ui_util.c \
    $(SRC_DIR)/crypto/whrlpool/wp_dgst.c \
    $(SRC_DIR)/crypto/x509/by_dir.c \
    $(SRC_DIR)/crypto/x509/by_file.c \
    $(SRC_DIR)/crypto/x509/by_mem.c \
    $(SRC_DIR)/crypto/x509/x509_addr.c \
    $(SRC_DIR)/crypto/x509/x509_akey.c \
    $(SRC_DIR)/crypto/x509/x509_akeya.c \
    $(SRC_DIR)/crypto/x509/x509_alt.c \
    $(SRC_DIR)/crypto/x509/x509_asid.c \
    $(SRC_DIR)/crypto/x509/x509_att.c \
    $(SRC_DIR)/crypto/x509/x509_bcons.c \
    $(SRC_DIR)/crypto/x509/x509_bitst.c \
    $(SRC_DIR)/crypto/x509/x509_cmp.c \
    $(SRC_DIR)/crypto/x509/x509_conf.c \
    $(SRC_DIR)/crypto/x509/x509_constraints.c \
    $(SRC_DIR)/crypto/x509/x509_cpols.c \
    $(SRC_DIR)/crypto/x509/x509_crld.c \
    $(SRC_DIR)/crypto/x509/x509_d2.c \
    $(SRC_DIR)/crypto/x509/x509_def.c \
    $(SRC_DIR)/crypto/x509/x509_err.c \
    $(SRC_DIR)/crypto/x509/x509_ext.c \
    $(SRC_DIR)/crypto/x509/x509_extku.c \
    $(SRC_DIR)/crypto/x509/x509_genn.c \
    $(SRC_DIR)/crypto/x509/x509_ia5.c \
    $(SRC_DIR)/crypto/x509/x509_info.c \
    $(SRC_DIR)/crypto/x509/x509_int.c \
    $(SRC_DIR)/crypto/x509/x509_issuer_cache.c \
    $(SRC_DIR)/crypto/x509/x509_lib.c \
    $(SRC_DIR)/crypto/x509/x509_lu.c \
    $(SRC_DIR)/crypto/x509/x509_ncons.c \
    $(SRC_DIR)/crypto/x509/x509_obj.c \
    $(SRC_DIR)/crypto/x509/x509_ocsp.c \
    $(SRC_DIR)/crypto/x509/x509_pcons.c \
    $(SRC_DIR)/crypto/x509/x509_pku.c \
    $(SRC_DIR)/crypto/x509/x509_pmaps.c \
    $(SRC_DIR)/crypto/x509/x509_policy.c \
    $(SRC_DIR)/crypto/x509/x509_prn.c \
    $(SRC_DIR)/crypto/x509/x509_purp.c \
    $(SRC_DIR)/crypto/x509/x509_r2x.c \
    $(SRC_DIR)/crypto/x509/x509_req.c \
    $(SRC_DIR)/crypto/x509/x509_set.c \
    $(SRC_DIR)/crypto/x509/x509_skey.c \
    $(SRC_DIR)/crypto/x509/x509_trs.c \
    $(SRC_DIR)/crypto/x509/x509_txt.c \
    $(SRC_DIR)/crypto/x509/x509_utl.c \
    $(SRC_DIR)/crypto/x509/x509_v3.c \
    $(SRC_DIR)/crypto/x509/x509_verify.c \
    $(SRC_DIR)/crypto/x509/x509_vfy.c \
    $(SRC_DIR)/crypto/x509/x509_vpm.c \
    $(SRC_DIR)/crypto/x509/x509cset.c \
    $(SRC_DIR)/crypto/x509/x509name.c \
    $(SRC_DIR)/crypto/x509/x509rset.c \
    $(SRC_DIR)/crypto/x509/x509spki.c \
    $(SRC_DIR)/crypto/x509/x509type.c \
    $(SRC_DIR)/crypto/x509/x_all.c \
    $(SRC_DIR)/crypto/compat/crypto_lock_win.c \
    $(SRC_DIR)/crypto/bio/b_win.c \
    $(SRC_DIR)/crypto/ui/ui_openssl_win.c \
    $(SRC_DIR)/crypto/compat/posix_win.c \
    $(SRC_DIR)/crypto/compat/bsd-asprintf.c \
    $(SRC_DIR)/crypto/compat/freezero.c \
    $(SRC_DIR)/crypto/compat/getopt_long.c \
    $(SRC_DIR)/crypto/compat/getpagesize.c \
    $(SRC_DIR)/crypto/compat/getprogname_windows.c \
    $(SRC_DIR)/crypto/compat/reallocarray.c \
    $(SRC_DIR)/crypto/compat/recallocarray.c \
    $(SRC_DIR)/crypto/compat/strcasecmp.c \
    $(SRC_DIR)/crypto/compat/strlcat.c \
    $(SRC_DIR)/crypto/compat/strlcpy.c \
    $(SRC_DIR)/crypto/compat/strndup.c \
    $(SRC_DIR)/crypto/compat/strsep.c \
    $(SRC_DIR)/crypto/compat/strtonum.c \
    $(SRC_DIR)/crypto/compat/syslog_r.c \
    $(SRC_DIR)/crypto/compat/timegm.c \
    $(SRC_DIR)/crypto/compat/explicit_bzero_win.c \
    $(SRC_DIR)/crypto/compat/arc4random.c \
    $(SRC_DIR)/crypto/compat/arc4random_uniform.c \
    $(SRC_DIR)/crypto/compat/getentropy_win.c \
    $(SRC_DIR)/crypto/compat/timingsafe_bcmp.c \
    $(SRC_DIR)/crypto/compat/timingsafe_memcmp.c

CRYPTO_OBJECTS = \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_core.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_cbc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/camellia.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmll_cbc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc4_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc4_skey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/wp_block.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cpt_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cryptlib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/crypto_init.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cversion.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ex_data.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/malloc-wrapper.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/mem_clr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/mem_dbg.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/o_fips.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/o_init.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/o_str.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_cfb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_ctr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_ecb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_ige.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_ofb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/aes_wrap.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_bitstr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_enum.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_int.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_mbstr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_object.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_octet.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_pkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_print.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_pubkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_strex.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_string.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_strnid.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_time.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_time_posix.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_time_tm.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_type.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/a_utf8.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ameth_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_gen.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_item.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_old.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_old_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_par.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn1_types.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn_mime.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/asn_moid.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_ndef.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p5_pbe.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p5_pbev2.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p8_pkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/t_crl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/t_req.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/t_spki.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/t_x509.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/t_x509a.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_dec.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_fre.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_new.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_typ.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/tasn_utl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_algor.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_attrib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_bignum.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_crl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_exten.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_info.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_long.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_name.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_pkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_pubkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_req.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_sig.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_spki.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_val.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_x509.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_x509a.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_cfb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_ecb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_ofb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_skey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/b_dump.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/b_print.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/b_sock.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_buff.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_nbio.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bf_null.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_cb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_meth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_acpt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_bio.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_conn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_dgram.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_fd.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_file.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_mem.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_null.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bss_sock.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_add.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_bpsw.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_const.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_convert.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_ctx.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_div.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_exp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_gcd.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_isqrt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_kron.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_mod.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_mod_sqrt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_mont.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_mul.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_prime.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_primitives.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_print.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_rand.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_recp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_shift.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_small_primes.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_sqr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bn_word.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/buf_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/buffer.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bs_ber.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bs_cbb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bs_cbs.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmll_cfb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmll_ctr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmll_ecb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmll_misc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmll_ofb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/c_cfb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/c_ecb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/c_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/c_ofb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/c_skey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/chacha.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cm_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cm_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cmac.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_att.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_dd.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_env.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_ess.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_io.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_kari.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_pwri.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_sd.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cms_smime.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_api.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_def.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_mall.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_mod.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/conf_sap.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_b64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_log.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_oct.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_policy.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_sct.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_sct_ctx.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_vfy.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ct_x509v3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/curve25519-generic.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/curve25519.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cbc_cksm.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cbc_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cfb64ede.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cfb64enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cfb_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/des_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecb3_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecb_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ede_cbcm_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/enc_read.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/enc_writ.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/fcrypt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/fcrypt_b.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ofb64ede.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ofb64enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ofb_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pcbc_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/qud_cksm.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rand_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/set_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/str2key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/xcbc_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_check.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_gen.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dh_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_gen.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_meth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_ossl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/dsa_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_check.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_curve.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_cvt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_kmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_mult.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_oct.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ec_print.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/eck_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecp_mont.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecp_oct.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecp_smpl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecx_methods.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecdh.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ecdsa.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/engine_stubs.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/err_all.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/err_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_b64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bio_md.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/c_all.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cipher_method_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/digest.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_aes.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_aes_cbc_hmac_sha1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_bf.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_camellia.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_cast.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_chacha.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_chacha20poly1305.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_des.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_des3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_gost2814789.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_idea.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_null.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_rc2.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_rc4.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_rc4_hmac_md5.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_sm4.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/e_xcbc_d.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/encode.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_aead.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_pbe.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/evp_pkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_gost2814789.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_gostr341194.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_md4.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_md5.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_md5_sha1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_null.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_ripemd.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_sha1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_sha3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_sigver.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_streebog.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_sm3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/m_wp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/names.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p5_crpt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p5_crpt2.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_dec.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_enc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_open.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_seal.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_sign.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p_verify.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pmeth_fn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pmeth_gn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pmeth_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost2814789.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost89_keywrap.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost89_params.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost89imit_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost89imit_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gost_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gostr341001.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gostr341001_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gostr341001_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gostr341001_params.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gostr341001_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gostr341194.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/streebog.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/hkdf.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/hm_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/hm_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/hmac.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/i_cbc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/i_cfb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/i_ecb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/i_ofb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/i_skey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/hkdf_evp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/kdf_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/lh_stats.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/lhash.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/md4.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/md5.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cbc128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ccm128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/cfb128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ctr128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/gcm128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ofb128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/xts128.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/o_names.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/obj_dat.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/obj_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/obj_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/obj_xref.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_asn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_cl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_ext.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_ht.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_srv.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ocsp_vfy.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_all.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_info.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_oth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_pk8.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_pkey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_sign.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_x509.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pem_xaux.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pvkfmt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_add.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_asn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_attr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_crpt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_crt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_decr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_init.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_key.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_kiss.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_mutl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_npas.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_p8d.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_p8e.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_sbag.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/p12_utl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk12err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk7_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk7_attr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk7_doit.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk7_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk7_mime.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pk7_smime.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/pkcs7err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/poly1305.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rand_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rand_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/randfile.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc2_cbc.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc2_ecb.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc2_skey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc2cfb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rc2ofb64.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ripemd.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_ameth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_blinding.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_chk.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_eay.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_gen.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_meth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_none.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_oaep.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_pk1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_pmeth.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_pss.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_saos.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_sign.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/rsa_x931.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/sha1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/sha256.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/sha3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/sha512.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/sm3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/sm4.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/stack.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_asn1.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_conf.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_req_print.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_req_utils.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_rsp_print.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_rsp_sign.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_rsp_utils.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_rsp_verify.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ts_verify_ctx.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/txt_db.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ui_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ui_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ui_null.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ui_util.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/wp_dgst.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/by_dir.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/by_file.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/by_mem.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_addr.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_akey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_akeya.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_alt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_asid.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_att.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_bcons.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_bitst.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_cmp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_conf.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_constraints.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_cpols.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_crld.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_d2.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_def.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_err.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_ext.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_extku.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_genn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_ia5.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_info.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_int.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_issuer_cache.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_lib.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_lu.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_ncons.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_obj.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_ocsp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_pcons.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_pku.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_pmaps.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_policy.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_prn.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_purp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_r2x.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_req.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_set.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_skey.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_trs.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_txt.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_utl.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_v3.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_verify.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_vfy.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509_vpm.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509cset.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509name.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509rset.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509spki.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x509type.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/x_all.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/crypto_lock_win.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/b_win.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/ui_openssl_win.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/posix_win.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/bsd-asprintf.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/freezero.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/getopt_long.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/getpagesize.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/getprogname_windows.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/reallocarray.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/recallocarray.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/strcasecmp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/strlcat.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/strlcpy.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/strndup.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/strsep.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/strtonum.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/syslog_r.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/timegm.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/explicit_bzero_win.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/arc4random.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/arc4random_uniform.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/getentropy_win.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/timingsafe_bcmp.obj \
    $(BUILD_DIR)/crypto_obj.dir/$(CONFIG)/timingsafe_memcmp.obj


$(SSL_LIB): $(SSL_OBJECTS)
	link /lib /nologo /machine:$(ARCH) /out:"$(SSL_LIB)" @<<
		$(SSL_OBJECTS)
<<

$(SSL_OBJECTS):
	cl /nologo /c $(SSL_FLAGS) $(SSL_FLAGS_CONFIG) $(CFLAGS_EXTRA) @<<
		$(SSL_SOURCES)
<<

$(CRYPTO_LIB): $(CRYPTO_OBJECTS)
	link /lib /nologo /machine:$(ARCH) /out:"$(CRYPTO_LIB)" @<<
		$(CRYPTO_OBJECTS)
<<

$(CRYPTO_OBJECTS):
	cl /nologo /c $(CRYPTO_FLAGS) $(CRYPTO_FLAGS_CONFIG) $(CFLAGS_EXTRA) @<<
		$(CRYPTO_SOURCES)
<<

